@@ -860,6 +860,7 @@ def convert_file(ofd_path, output_dir=None):
 def convert_folder(input_dir):
     """批量转换指定目录及其所有子目录中的OFD文件到PNG，每个包含OFD文件的目录会创建img文件夹存储结果"""
     import os
+    results = []
     # 检测输入目录是否存在
     if not os.path.isdir(input_dir):
         raise NotADirectoryError(f"输入目录不存在: {input_dir}")
@@ -909,12 +910,12 @@ def convert_folder(input_dir):
                         # 构建源和目标路径
                         src_path = os.path.join(temp_output, img_filename)
                         dst_path = os.path.join(output_dir, new_img_filename)
-
+                        print(f"图片路径: {dst_path}")
                         # 移动并替换图片
                         os.replace(src_path, dst_path)
                         # 打印图片路径和图片名称和开始时间到转换时间的差，精确到毫秒，比如：125ms
                         print(f"************************已转换并保存图片: {output_dir}\{new_img_filename} ->转换时间: {(datetime.datetime.now() - start_time).total_seconds() * 1000:.0f}ms")
-                        
+                        results.append(out_path)
 
             except Exception as e:
                 print(f'转换文件 {os.path.join(root, filename)} 失败: {str(e)}')
